@@ -3,10 +3,14 @@
  */
 
 #include <unistd.h>
+#include <fcntl.h>
+#include <string.h>
 #include <errno.h>
 #include <sys/time.h>
 #include <sys/file.h>
 
+#include "params.h"
+
 int sleep_select(int sec, int usec)
 {
 	struct timeval timeout;
@@ -17,12 +21,44 @@ int sleep_select(int sec, int usec)
 	return select(0, NULL, NULL, NULL, &timeout);
 }
 
-int flock_loop(int fd)
+int lock_fd(int fd, int shared)
 {
-	while (flock(fd, LOCK_EX)) {
+#if LOCK_FCNTL
+	struct flock l;
+
+	memset(&l, 0, sizeof(l));
+	l.l_whence = SEEK_SET;
+	l.l_type = shared ? F_RDLCK : F_WRLCK;
+	while (fcntl(fd, F_SETLKW, &l)) {
 		if (errno != EBUSY) return -1;
 		sleep_select(1, 0);
 	}
+#endif
+
+#if LOCK_FLOCK
+	while (flock(fd, shared ? LOCK_SH : LOCK_EX)) {
+		if (errno != EBUSY) return -1;
+		sleep_select(1, 0);
+	}
+#endif
+
+	return 0;
+}
+
+int unlock_fd(int fd)
+{
+#if LOCK_FCNTL
+	struct flock l;
+
+	memset(&l, 0, sizeof(l));
+	l.l_whence = SEEK_SET;
+	l.l_type = F_UNLCK;
+	if (fcntl(fd, F_SETLK, &l)) return -1;
+#endif
+
+#if LOCK_FLOCK
+	if (flock(fd, LOCK_UN)) return -1;
+#endif
 
 	return 0;
 }
